@@ -11,6 +11,7 @@ from orm_collector.manager import SessionCollector
 from rich import print
 from pathlib import Path
 import aioredis
+from networktools.time import now
 
 app = FastAPI()
 
@@ -69,6 +70,7 @@ def get_db():
     except Exception as e:
         print("Error al crear sesion",e)
     finally:
+        print(now(), "Closing database connection")
         session.close()
 
 @app.get("/")
